@@ -1,4 +1,15 @@
-test_that("flipLoadings throws no errors", {
+test_that("flipLoadings throws no errors when the subject metadata contains strings", {
+  set.seed(123)
+
+  A = array(rnorm(108*2), c(108,2))
+  B = array(rnorm(100*2), c(100,2))
+  C = array(rnorm(10*2), c(10,2))
+  X = reinflateTensor(A, B, C)
+  models = parafac(X, 2, nstart=10, output="all", sortComponents=TRUE)
+  expect_no_error(flipLoadings(models, X))
+})
+
+test_that("flipLoadings throws no errors when the subject metadata contains integers", {
   set.seed(123)
 
   A = array(rnorm(108*2), c(108,2))
@@ -160,3 +171,4 @@ test_that("vect_to_fac resorts components", {
   newFac = vect_to_fac(v, X, sortComponents=TRUE)
   expect_false(all(unlist(Fac) == unlist(newFac)))
 })
+
